#!/usr/bin/python
# -*- coding: utf-8 -*-
### BEGIN LICENSE
# Copyright (C) 2010 Rick Spencer <rick.spencer@canonical.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import sys
import os
import gtk
import gst

import gettext
from gettext import gettext as _
gettext.textdomain('gstreamer-webcam')

class MediaBox(gtk.VBox):
    _default_pipeline_string = """v4l2src !
                                  videorate ! 
                                  video/x-raw-yuv,framerate=%i/1 !
                                  autovideosink"""

    def __init__(self):
        gtk.VBox.__init__(self, False, 5)
        self.video_window = gtk.DrawingArea()
        self.pack_start(self.video_window, True, True)
        self.video_window.show()
        self._video_frame_rate = 5
        self._pipline_string = self._default_pipeline_string % self._video_frame_rate
        self.player = None
        self.connect("destroy", self.on_destroy)

    @property
    def video_frame_rate(self):
        return self._video_frame_rate

    @video_frame_rate.setter
    def video_frame_rate(self, fps):
        self._pipline_string = self._default_pipeline_string % fps
        self.stop()
        self._set_pipeline()

    def _set_pipeline(self):
        print self._pipline_string
        self.player = gst.parse_launch(self._pipline_string)

        bus = self.player.get_bus()
        bus.add_signal_watch()
        bus.enable_sync_message_emission()
        bus.connect("message", self.on_message)
        bus.connect("sync-message::element", self.on_sync_message)

    def play(self):
        self.stop()
        self._set_pipeline()
        self.player.set_state(gst.STATE_PLAYING)

    def stop(self):
        if self.player is not None:
            self.player.set_state(gst.STATE_NULL)

    def on_message(self, bus, message):
        t = message.type
        if t == gst.MESSAGE_EOS:
            self.player.set_state(gst.STATE_NULL)
        elif t == gst.MESSAGE_ERROR:
            err, debug = message.parse_error()
            print "Error: %s" % err, debug
            self.player.set_state(gst.STATE_NULL)

    def on_sync_message(self, bus, message):
        if message.structure is None:
            return
        message_name = message.structure.get_name()
        if message_name == "prepare-xwindow-id":
            imagesink = message.src
            imagesink.set_property("force-aspect-ratio", True)
            imagesink.set_xwindow_id(self.video_window.window.xid)

    def on_destroy(self, widget, data=None):
        self.player.set_state(gst.STATE_NULL)
        
